package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.LiftDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.LiftDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.LiftDataRequest;
import cn.com.ty.lift.batch.applet.util.DataStatisticsUtil;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class LiftDataService {

    @Resource
    private LiftDataMapper liftDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 终止时间
     * @return
     * @description 将电梯数据放入redis中
     * @date 2020/2/4 10:24 上午
     */
    public void putLiftDataListToRedis(CommonRequest commonRequest) {
        List<LiftDataModel> liftDataModelList = liftDataMapper.getLiftDataList(commonRequest);
        //通过公司id将数据进行分组,并将数据放入redis中
        DataStatisticsUtil.putStatisticsDataToRedis(liftDataModelList, redisTemplate,
                DataStatisticsConstants.LIFT_DATA_FIELD);
    }

    /**
     * @param liftDataRequest 起始时间 终止时间
     * @return
     * @description
     * @date 2020/2/4 10:36 上午
     */
    public List<LiftDataModel> getLiftDataListFromRedis(LiftDataRequest liftDataRequest) {
        //从redis中获取当前公司电梯信息
        List<LiftDataModel> liftDataModelList = (List<LiftDataModel>)
                DataStatisticsUtil.getStatisticsDataFromRedis(redisTemplate,
                        DataStatisticsConstants.LIFT_DATA_FIELD, liftDataRequest.getMtCompanyId());
        if (liftDataModelList != null) {
            //过滤起始时间之前的数据
            if (liftDataRequest.getStartTimeDate() != null) {
                liftDataModelList = liftDataModelList.stream()
                        .filter(a -> a.getConnectTime().isAfter(liftDataRequest.getStartTimeDate()))
                        .collect(Collectors.toList());
            }
            //过滤终止时间之后的数据
            if (liftDataRequest.getEndTimeDate() != null) {
                liftDataModelList = liftDataModelList.stream()
                        .filter(a -> a.getConnectTime().isBefore(liftDataRequest.getEndTimeDate()))
                        .collect(Collectors.toList());
            }
        }
        return liftDataModelList;
    }

    /**
     * @param
     * @return
     * @description 获取不同状态下的电梯数量 1:新增 2:在保 3:丢失
     * @date 2020/2/5 12:28 下午
     */
    public RestResponse liftOverView(LiftDataRequest liftDataRequest) {
        Map<Integer, Integer> liftStatusToNums = DataStatisticsConstants.LIFT_STATUS_TO_LIFT_NUM;
        return RestResponse.success(liftStatusToNums, ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 站点排名
     * @date 2020/2/5 2:43 下午
     */
    public RestResponse regionRank(LiftDataRequest liftDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 项目电梯数量
     * @date 2020/2/5 4:46 下午
     */
    public RestResponse projectLiftNums(LiftDataRequest liftDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }
}
