package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.PaymentDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.PaymentDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.PaymentDataRequest;
import cn.com.ty.lift.batch.applet.util.DataStatisticsUtil;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class PaymentDataService {

    @Resource
    private PaymentDataMapper paymentDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 结束时间
     * @return
     * @description 将收款数据放入redis中
     * @date 2020/2/4 2:20 下午
     */
    public void putPaymentDataToRedis(CommonRequest commonRequest) {
        List<PaymentDataModel> paymentDataModelList = paymentDataMapper.getPaymentDataList(commonRequest);
        //将收款数据放入redis中
        DataStatisticsUtil.putStatisticsDataToRedis(paymentDataModelList, redisTemplate,
                DataStatisticsConstants.PAYMENT_DATA_FIELD);
    }

    /**
     * @param paymentDataRequest
     * @return
     * @description 从redis中获取收款数据
     * @date 2020/2/4 2:30 下午
     */
    public List<PaymentDataModel> getPaymentDataListFromRedis(PaymentDataRequest paymentDataRequest) {
        //从redis中获取当前公司的收款数据
        List<PaymentDataModel> paymentDataModelList = (List<PaymentDataModel>)
                DataStatisticsUtil.getStatisticsDataFromRedis(redisTemplate,
                        DataStatisticsConstants.PAYMENT_DATA_FIELD, paymentDataRequest.getMtCompanyId());
        if (paymentDataModelList != null && paymentDataModelList.size() > 0) {
            //通过公司id过滤
            paymentDataModelList = paymentDataModelList.stream()
                    .filter(a -> a.getMtCompanyId().equals(paymentDataRequest.getMtCompanyId()))
                    .collect(Collectors.toList());
        }
        return paymentDataModelList;
    }

    /**
     * @param
     * @return
     * @description 收款数据总览
     * @date 2020/2/5 4:55 下午
     */
    public RestResponse paymentOverView(PaymentDataRequest paymentDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 站点排名
     * @date 2020/2/5 5:00 下午
     */
    public RestResponse regionRank(PaymentDataRequest paymentDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 超期项目统计
     * @date 2020/2/5 5:02 下午
     */
    public RestResponse dueToProject(PaymentDataRequest paymentDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }
}
